@@ -16,6 +16,12 @@ if(run.inspect.apsimx.json){
   inspect_apsimx_json("Maize.apsimx", src.dir = extd.dir, parm = "Clock")
   
   inspect_apsimx_json("Maize.apsimx", src.dir = extd.dir, parm = "Soil") 
+  
+  inspect_apsimx_json("Maize.apsimx", src.dir = extd.dir, parm = "Soil") 
+  
+  inspect_apsimx_json("Maize.apsimx", src.dir = extd.dir, parm = "Dekalb") 
+  
+  inspect_apsimx_json("Maize.apsimx", src.dir = extd.dir, parm = "10-jan") 
 
   ## These parameters do not return a single path
   ## Ideally, I would be able to either return multiple paths or use
